# TorchFEM: Another Finite Element Package...in PyTorch

## Introduction

TorchFEM is a compact finite element library based on PyTorch taking advantage of the auto-differentiation of PyTorch to speed up the traditional finite element pipeline, instead of train a black-box model to "solve" PDE. The code base is modified based on the popular MATLAB package [iFEM by Dr. Long Chen](https://lyc102.github.io/ifem/).
